==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/OwaspCrsExclusionEntryResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Allow to exclude some variable satisfy the condition for the WAF check.
 * @property exclusionManagedRuleSets The managed rule sets that are associated with the exclusion.
 * @property matchVariable The variable to be excluded.
 * @property selector When matchVariable is a collection, operator used to specify which elements in the collection this exclusion applies to.
 * @property selectorMatchOperator When matchVariable is a collection, operate on the selector to specify which elements in the collection this exclusion applies to.
 */
public data class OwaspCrsExclusionEntryResponse(
    public val exclusionManagedRuleSets: List<ExclusionManagedRuleSetResponse>? = null,
    public val matchVariable: String,
    public val selector: String,
    public val selectorMatchOperator: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.OwaspCrsExclusionEntryResponse):
            OwaspCrsExclusionEntryResponse = OwaspCrsExclusionEntryResponse(
            exclusionManagedRuleSets = javaType.exclusionManagedRuleSets().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.network.kotlin.outputs.ExclusionManagedRuleSetResponse.Companion.toKotlin(args0)
                })
            }),
            matchVariable = javaType.matchVariable(),
            selector = javaType.selector(),
            selectorMatchOperator = javaType.selectorMatchOperator(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/outputs/OwaspCrsExclusionEntryResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.outputs

import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Allow to exclude some variable satisfy the condition for the WAF check.
 * @property exclusionManagedRuleSets The managed rule sets that are associated with the exclusion.
 * @property matchVariable The variable to be excluded.
 * @property selector When matchVariable is a collection, operator used to specify which elements in the collection this exclusion applies to.
 * @property selectorMatchOperator When matchVariable is a collection, operate on the selector to specify which elements in the collection this exclusion applies to.
 */
public data class OwaspCrsExclusionEntryResponse(
    public val exclusionManagedRuleSets: List<ExclusionManagedRuleSetResponse>? = null,
    public val matchVariable: String,
    public val selector: String,
    public val selectorMatchOperator: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.outputs.OwaspCrsExclusionEntryResponse): OwaspCrsExclusionEntryResponse = OwaspCrsExclusionEntryResponse(
            exclusionManagedRuleSets = javaType.exclusionManagedRuleSets().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.network.kotlin.outputs.ExclusionManagedRuleSetResponse.Companion.toKotlin(args0)
                })
            }),
            matchVariable = javaType.matchVariable(),
            selector = javaType.selector(),
            selectorMatchOperator = javaType.selectorMatchOperator(),
        )
    }
}
